% MassCal.m

pkg load symbolic
%calculate solution to reciprocity calibration with syms

syms Zm Ze ToSq ZinL1 ZinL2 ZinL3 ZL1 ZL2 ZL3

% this equation assumes an anti-reciprocal system
ZinL1_Alg = Ze + ToSq/(ZL1 + Zm);
ZinL2_Alg = Ze + ToSq/(ZL2 + Zm);
ZinL3_Alg = Ze + ToSq/(ZL3 + Zm);


% eliminate Ze
% SRR: The problem is these choices are not unique
EQ1 = simplify(ZinL1_Alg -ZinL2_Alg);
EQ2 = simplify(ZinL2_Alg - ZinL3_Alg);

ToSq_Zm = simplify(solve(EQ1 == (ZinL1-ZinL2),ToSq));
EQ2_Zm = simplify(subs(EQ2,ToSq,ToSq_Zm));
Zm_sol = (solve(EQ2_Zm==(ZinL2-ZinL3),Zm));
ToSq_sol = simplify(subs(ToSq_Zm,Zm,Zm_sol));

ZinL1_Alg2 = subs(ZinL1_Alg,Zm,Zm_sol);
ZinL1_Alg3 = subs(ZinL1_Alg2,ToSq,ToSq_sol);
Ze_sol = simplify(solve(ZinL1_Alg3==ZinL1,Ze));

% I had to factor others by hand, but ToSq can be factored by syms
%[nToSq_sol,dToSq_sol] = numden(ToSq_sol);
%ToSq_sol = factor(nToSq_sol)/factor(dToSq_sol);


%% Check with Ramo 1965 Equations:
Ze_Ramo = ((ZinL1-ZinL3).*(ZinL1*ZL1-ZinL2*ZL2)-(ZinL1-ZinL2).*(ZinL1*ZL1-ZinL3*ZL3))./...
  ((ZinL1-ZinL3)*(ZL1-ZL2)-(ZinL1-ZinL2)*(ZL1-ZL3));
shouldBe0 =  simplify(Ze_sol-Ze_Ramo); % is 0 - same result!
Zm_Ramo = ((ZinL1*ZL1-ZinL2*ZL2)-Ze_Ramo*(ZL1-ZL2))./(ZinL2-ZinL1);
shouldBe0 = simplify(Zm_sol-Zm_Ramo); % is 0 - same result!
% ToSq
ToSq_Ramo1 = simplify((ZinL1-Ze_Ramo)*(Zm_Ramo+ZL1)); mightBe01 = simplify(ToSq_Ramo1 - ToSq_sol); % is 0 - same result!
ToSq_Ramo2 = simplify((ZinL2-Ze_Ramo)*(Zm_Ramo+ZL2)); mightBe02 = simplify(ToSq_Ramo2 - ToSq_sol); % is 0 - same result!
ToSq_Ramo3 = simplify((ZinL3-Ze_Ramo)*(Zm_Ramo+ZL3)); mightBe03 = simplify(ToSq_Ramo3 - ToSq_sol); % is 0 - same result!

%% Check with Noori 2013 Equations
X = ((ZL2-ZL3)*(ZinL3-ZinL1))./((ZL3-ZL1)*(ZinL2-ZinL3));
Zm_Noori = simplify((X*ZL1-ZL2)./(1-X));
ToSq_Noori = simplify((ZinL3-ZinL1)*(Zm_Noori+ZL3)*(Zm_Noori+ZL1)/(ZL1-ZL3));
Ze_Noori = simplify(ZinL1-ToSq_Noori/(ZL1+Zm_Noori));

shouldBe0Ze = simplify(Ze_sol-Ze_Noori); % is 0 - same result!
shouldBe0Zm = simplify(Zm_sol-Zm_Noori); % is 0 - same result!
shouldBe0T = simplify(ToSq_sol-ToSq_Noori); % is 0 - same result!